import FormCheck from "@/components/CheckBoxComponent/FormCheck";
import {
  CloseDisclosure,
  Edit,
  OpenDisclosure,
  PrimaryLogout,
  Trash,
} from "@/components/Icons";
import { Disclosure } from "@headlessui/react";
import axios from "axios";
import Image from "next/image";
import { useEffect, useState } from "react";
import Swal from "sweetalert2";
import "./style.css";

export const MyProfileTab = ({ activeTab }) => {
  const [selectedTabIdx, setSelectedTabIdx] = useState(activeTab);
  const [file, setFile] = useState(null);
  const [preview, setPreview] = useState(null);
  const [user, setUser] = useState({});
  const [userId, setUserId] = useState("664761659d34b4208fafa189");
  const [isEditing, setIsEditing] = useState(false);

  useEffect(() => {
    axios
      .get(`${process.env.NEXT_PUBLIC_BASE_URL}/assetHolder/${userId}`)
      .then((response) => {
        setUser(response.data);
      })
      .catch((error) => {
        console.error("There was an error fetching the user!", error);
      });
  }, [userId]);

  const handleFileChange = (e) => {
    const selectedFile = e.target.files[0];
    setFile(selectedFile);
    setPreview(URL.createObjectURL(selectedFile));
  };

  const handleRemoveFile = () => {
    setFile(null);
    setPreview(null);
  };

  const handleInputChange = (e) => {
    const { name, value } = e.target;
    setUser({ ...user, [name]: value });
  };

  const handleSaveChanges = () => {
    axios
      .put(
        `${process.env.NEXT_PUBLIC_BASE_URL}/assetHolder/update-user/${userId}`,
        user
      )
      .then((response) => {
        console.log("User updated successfully!", response.data);
        setIsEditing(false);
        Swal.fire({
          icon: "success",
          title: "Success",
          text: "User updated successfully!",
        });
      })
      .catch((error) => {
        console.error("There was an error updating the user!", error);
        Swal.fire({
          icon: "error",
          title: "Error",
          text: "There was an error updating the user.",
        });
      });
  };

  const handleDeleteUser = () => {
    axios
      .delete(`${process.env.NEXT_PUBLIC_BASE_URL}/assetHolder/delete-user`, {
        data: { id: userId },
      })
      .then((response) => {
        console.log("User deleted successfully!", response.data);
      })
      .catch((error) => {
        console.error("There was an error deleting the user!", error);
      });
  };

  const tabs = [
    { name: "Overview", current: selectedTabIdx === 0 },
    { name: "Edit Profile", current: selectedTabIdx === 1 },
    { name: "Security", current: selectedTabIdx === 2 },
    { name: "Change Password", current: selectedTabIdx === 3 },
  ];

  const overview = [
    { key: "Full Name", value: user.fullName },
    { key: "Phone", value: user.phone },
    { key: "Email", value: user.email },
    { key: "Role", value: user.role },
    { key: "Gender", value: user.gender },
    {
      key: "Date of birth",
      value: new Date(user.dateOfBirth).toLocaleDateString(),
    },
    { key: "Nationality", value: user.country },
    { key: "Religion", value: user.religion },
    { key: "Address", value: user.address },
  ];

  return (
    <>
      <span className="text-lg text-prussianBlue/40 mb-4 block">
        My Profile
      </span>
      <div className="custom-shadow rounded">
        <div className="primary-gradient border border-black rounded px-12 overflow-x-auto">
          <nav className="flex justify-between gap-3 w-full" aria-label="Tabs">
            {tabs.map((tab, i) => (
              <a
                key={tab.name}
                className={`whitespace-nowrap py-4 cursor-pointer text-xl ${
                  tab.current
                    ? "text-white border-b-4 border-white focus:outline-none "
                    : ""
                }`}
                onClick={() => setSelectedTabIdx(i)}
              >
                {tab.name}
              </a>
            ))}
          </nav>
        </div>
        {selectedTabIdx === 0 && (
          <div className="p-12">
            <h3 className="mb-3 text-prussianBlue text-2xl font-medium">
              About / Asset Holder
            </h3>
            <p className="text-lg mb-12">{user.about}</p>
            <h4 className="text-prussianBlue mb-7 text-2xl font-medium">
              Profile Details
            </h4>
            <div className="flex flex-col gap-4 text-xl">
              {overview.map((ele, i) => (
                <div key={i} className="flex">
                  <h4 className="w-[30%] font-medium">{ele.key}</h4>{" "}
                  <span className="text-black/60">{ele.value}</span>
                </div>
              ))}
            </div>
          </div>
        )}
        {selectedTabIdx === 1 && (
          <div className="p-12">
            <div className="flex gap-10 mb-16">
              <h2 className="text-prussianBlue text-xl font-medium">
                Profile Image{" "}
              </h2>
              <figure className="rounded-full relative shrink-0">
                <Image
                  className="rounded-full object-cover h-[170px] w-[170px]"
                  src={`${
                    preview ? preview : "/assets/images/seller-profile.png"
                  }`}
                  height={177}
                  width={177}
                  alt="profile"
                />
                <div className="absolute flex py-4 bg-white/60 gap-6 justify-center w-full bottom-0">
                  <label className="cursor-pointer" htmlFor="image-lpload">
                    <input
                      type="file"
                      onChange={handleFileChange}
                      className="hidden"
                      id="image-lpload"
                    />
                    <PrimaryLogout className="h-[24px] w-[24px] -rotate-90" />
                  </label>
                  <button onClick={handleRemoveFile}>
                    <Trash />
                  </button>
                </div>
              </figure>
            </div>
            <div className="flex flex-col gap-5 mb-7">
              <div className="flex">
                <h3 className="w-[30%]">Full Name</h3>
                <input
                  type="text"
                  className="shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input"
                  placeholder="Full Name"
                  name="fullName"
                  value={user.fullName}
                  onChange={handleInputChange}
                />
              </div>
              <div className="flex">
                <h3 className="w-[30%]">About</h3>
                <textarea
                  type="text"
                  rows={4}
                  className="shadow-neons rounded w-full py-3 px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input"
                  placeholder="About"
                  name="about"
                  value={user.about}
                  onChange={handleInputChange}
                />
              </div>
              <div className="flex">
                <h3 className="w-[30%]">Role</h3>
                <input
                  type="text"
                  className="shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input"
                  placeholder="Role"
                  name="role"
                  value={user.role}
                  onChange={handleInputChange}
                />
              </div>
              <div className="flex">
                <h3 className="w-[30%]">Country</h3>
                <input
                  type="text"
                  className="shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input"
                  placeholder="Country"
                  name="country"
                  value={user.country}
                  onChange={handleInputChange}
                />
              </div>
              <div className="flex">
                <h3 className="w-[30%]">Address</h3>
                <input
                  type="text"
                  className="shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input"
                  placeholder="Address"
                  name="address"
                  value={user.address}
                  onChange={handleInputChange}
                />
              </div>
              <div className="flex">
                <h3 className="w-[30%]">Phone</h3>
                <input
                  type="text"
                  className="shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input"
                  placeholder="Phone"
                  name="phone"
                  value={user.phone}
                  onChange={handleInputChange}
                />
              </div>
              <div className="flex">
                <h3 className="w-[30%]">Email</h3>
                <input
                  type="email"
                  className="shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input"
                  placeholder="Email"
                  name="email"
                  value={user.email}
                  onChange={handleInputChange}
                />
              </div>
              <div className="flex">
                <h3 className="w-[30%]">Gender</h3>
                <div className="flex gap-10 text-black/50">
                  <label className="cursor-pointer" htmlFor="Male">
                    <input
                      type="radio"
                      name="gender"
                      id="Male"
                      value="Male"
                      checked={user.gender === "Male"}
                      onChange={handleInputChange}
                    />{" "}
                    Male
                  </label>
                  <label className="cursor-pointer" htmlFor="Female">
                    <input
                      type="radio"
                      name="gender"
                      id="Female"
                      value="Female"
                      checked={user.gender === "Female"}
                      onChange={handleInputChange}
                    />{" "}
                    Female
                  </label>
                  <label className="cursor-pointer" htmlFor="Other">
                    <input
                      type="radio"
                      name="gender"
                      id="Other"
                      value="Other"
                      checked={user.gender === "Other"}
                      onChange={handleInputChange}
                    />{" "}
                    Other
                  </label>
                </div>
              </div>
              <div className="flex">
                <h3 className="w-[30%]">Religion</h3>
                <input
                  type="text"
                  className="shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input"
                  placeholder="Religion"
                  name="religion"
                  value={user.religion}
                  onChange={handleInputChange}
                />
              </div>
              <div className="flex">
                <h3 className="w-[30%]">Date Of Birth</h3>
                <input
                  type="text"
                  className="shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input"
                  placeholder="Date Of Birth"
                  name="dateOfBirth"
                  value={new Date(user.dateOfBirth).toLocaleDateString()}
                  onChange={handleInputChange}
                />
              </div>
              <div className="flex relative">
                <h3 className="w-[30%]">Twitter Profile</h3>
                <input
                  type="text"
                  className="shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input"
                  placeholder="Twitter Profile"
                  name="twitter"
                  value={user.socialProfiles?.twitter}
                  onChange={handleInputChange}
                />
                <button className="absolute right-3 top-4">
                  <Edit />
                </button>
              </div>
              <div className="flex relative">
                <h3 className="w-[30%]">Facebook Profile</h3>
                <input
                  type="text"
                  className="shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input"
                  placeholder="Facebook Profile"
                  name="facebook"
                  value={user.socialProfiles?.facebook}
                  onChange={handleInputChange}
                />
                <button className="absolute right-3 top-4">
                  <Edit />
                </button>
              </div>
              <div className="flex relative">
                <h3 className="w-[30%]">Instagram Profile</h3>
                <input
                  type="text"
                  className="shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input"
                  placeholder="Instagram Profile"
                  name="instagram"
                  value={user.socialProfiles?.instagram}
                  onChange={handleInputChange}
                />
                <button className="absolute right-3 top-4">
                  <Edit />
                </button>
              </div>
              <div className="flex relative">
                <h3 className="w-[30%]">Linkedin Profile</h3>
                <input
                  type="text"
                  className="shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input"
                  placeholder="Linkedin Profile"
                  name="linkedin"
                  value={user.socialProfiles?.linkedin}
                  onChange={handleInputChange}
                />
                <button className="absolute right-3 top-4">
                  <Edit />
                </button>
              </div>
              <div className="flex relative">
                <h3 className="w-[30%]">Tiktok Profile</h3>
                <input
                  type="text"
                  className="shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input"
                  placeholder="Tiktok Profile"
                  name="tiktok"
                  value={user.socialProfiles?.tiktok}
                  onChange={handleInputChange}
                />
                <button className="absolute right-3 top-4">
                  <Edit />
                </button>
              </div>
            </div>
            <button
              className="px-6 py-3 mx-auto block rounded primary-gradient text-white"
              onClick={handleSaveChanges}
            >
              Save Changes
            </button>
            {/* <button
              className="px-6 py-3 mx-auto block rounded primary-gradient text-white bg-red-500 mt-4"
              onClick={handleDeleteUser}
            >
              Delete User
            </button> */}
          </div>
        )}
        {selectedTabIdx === 2 && (
          <div className="p-12">
            <Disclosure as="div" className={`mb-4`} defaultOpen={true}>
              {({ open }) => (
                <>
                  <Disclosure.Button
                    className={`w-full custom-shadow rounded py-3 px-7 gap-4 flex-wrap justify-between items-center flex ${
                      open && "mb-3"
                    }`}
                  >
                    <span className="whitespace-nowrap">
                      2-Step Verification
                    </span>
                    <span className="whitespace-nowrap">
                      On since 22 April 2024
                    </span>
                    <span className="flex-shrink-0">
                      {open ? (
                        <OpenDisclosure className="text-prussianBlue" />
                      ) : (
                        <CloseDisclosure className="text-prussianBlue" />
                      )}
                    </span>
                  </Disclosure.Button>
                  <Disclosure.Panel as="div" className="px-7 py-4">
                    <p className="mb-2">
                      {"Your account is protected with 2-Step Verification"}
                    </p>
                    <p className="mb-4 text-black/60">
                      {
                        "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat."
                      }
                    </p>
                    <button className="py-2 px-8 primary-gradient rounded">
                      Turn Off 2-Step Verification{" "}
                    </button>
                  </Disclosure.Panel>
                </>
              )}
            </Disclosure>
            <Disclosure as="div" className={`mb-4`} defaultOpen={true}>
              {({ open }) => (
                <>
                  <Disclosure.Button
                    className={`w-full custom-shadow rounded py-3 px-7 gap-4 justify-between items-center flex ${
                      open && "mb-3"
                    }`}
                  >
                    <span className="whitespace-nowrap">
                      Email Verification
                    </span>
                    <span className="flex-shrink-0">
                      {open ? (
                        <OpenDisclosure className="text-prussianBlue" />
                      ) : (
                        <CloseDisclosure className="text-prussianBlue" />
                      )}
                    </span>
                  </Disclosure.Button>
                  <Disclosure.Panel
                    as="div"
                    className="px-7 py-4 flex  flex-col items-start gap-4"
                  >
                    <p>Verify Your Email </p>
                    <input
                      type="email"
                      className="shadow-neons rounded w-full sm:w-[50%] h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input"
                      placeholder="example@gmail.com"
                      name="email"
                    />
                    <button className="py-2 px-4 primary-gradient rounded">
                      Verify
                    </button>
                  </Disclosure.Panel>
                </>
              )}
            </Disclosure>
            <Disclosure as="div" className={`mb-4`} defaultOpen={true}>
              {({ open }) => (
                <>
                  <Disclosure.Button
                    className={`w-full custom-shadow rounded py-3 px-7 gap-4 flex-wrap justify-between items-center flex ${
                      open && "mb-3"
                    }`}
                  >
                    <span className="whitespace-nowrap">Recovery email</span>
                    <span className="whitespace-nowrap">Add Email Address</span>
                    <span className="flex-shrink-0">
                      {open ? (
                        <OpenDisclosure className="text-prussianBlue" />
                      ) : (
                        <CloseDisclosure className="text-prussianBlue" />
                      )}
                    </span>
                  </Disclosure.Button>
                  <Disclosure.Panel
                    as="div"
                    className="px-7 py-4 flex  flex-col items-start gap-4"
                  >
                    <p>Add Your Recovery email</p>
                    <input
                      type="email"
                      className="shadow-neons rounded w-full sm:w-[50%] h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input"
                      placeholder="example@gmail.com"
                      name="email"
                    />
                    <div className="flex gap-8">
                      <button className="py-2 px-4 primary-gradient rounded">
                        Next
                      </button>
                      <button className="text-prussianBlue">Cancel</button>
                    </div>
                  </Disclosure.Panel>
                </>
              )}
            </Disclosure>
          </div>
        )}
        {selectedTabIdx === 3 && (
          <div className="p-12">
            <Disclosure as="div" className={`mb-4`} defaultOpen={true}>
              {({ open }) => (
                <>
                  <Disclosure.Button
                    className={`w-full custom-shadow rounded py-3 px-7 gap-4 flex-wrap justify-between items-center flex ${
                      open && "mb-3"
                    }`}
                  >
                    <span className="whitespace-nowrap">Password</span>
                    <span className="whitespace-nowrap">
                      Last changed 22 April 2024
                    </span>
                    <span className="flex-shrink-0">
                      {open ? (
                        <OpenDisclosure className="text-prussianBlue" />
                      ) : (
                        <CloseDisclosure className="text-prussianBlue" />
                      )}
                    </span>
                  </Disclosure.Button>
                  <Disclosure.Panel
                    as="div"
                    className="grid gap-4 sm:gap-12 sm:grid-cols-2 px-7 py-4"
                  >
                    <div>
                      <p className="mb-5">Choose a strong password</p>
                      <input
                        type="password"
                        className="mb-4 shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input"
                        placeholder="Old Password*"
                        name="oldPassword"
                      />
                      <input
                        type="password"
                        className="mb-4 shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input"
                        placeholder="New Password*"
                        name="newPassword"
                      />
                      <input
                        type="password"
                        className="mb-4 shadow-neons rounded w-full h-[48px] px-5 placeholder:text-dark-grey outline-with-opacity placeholder:text-[15px] placeholder:font-normal card-number-input"
                        placeholder="Re-Type New Password*"
                        name="retypeNewPassword"
                      />
                      <div className="flex gap-4">
                        <button className="py-2 px-4 primary-gradient rounded">
                          Change Password
                        </button>
                        <button className="text-prussianBlue rounded">
                          Cancel
                        </button>
                      </div>
                    </div>
                    <div className="flex flex-col gap-2">
                      <p className="mb-7">Password Requirements</p>
                      <FormCheck label="Minimum 8 Characters" id="1" />
                      <FormCheck label="UPPERCASE letter" id="2" />
                      <FormCheck label="lowercase letter" id="3" />
                      <FormCheck label="Numbers" id="4" />
                      <FormCheck label="Special Symbols" id="5" />
                    </div>
                  </Disclosure.Panel>
                </>
              )}
            </Disclosure>
          </div>
        )}
      </div>
    </>
  );
};
